'use strict';
const viewsSchemas = require('./../../../../viewsSchemas');


const {
  classified
} = viewsSchemas;


module.exports = {
  name: 'classified',
  title: '归类管理',
  vuex: true,
  model: [
    {
      mapFn: 'getByNameSearchList',
      isRule: false,
      title: '名字搜索数据列表',
      path: classified.getByNameSearchList,
      params: {
        xsiteid: ['站点ID', 'String', '必填'],
        film_name: ['归类ID', 'String', '必填'],
      },
      disabled: true,
      role: 'getByNameSearchList',
    },

    {
      mapFn: 'getByIdClassified',
      isRule: false,
      title: '获取详情',
      path: classified.getByIdClassified,
      params : {
        xsiteid: ['站点ID', 'String', '必填'],
        category_id: ['归类ID', 'String', '必填'],
      },
      disabled: true,
      role: 'getByIdClassified',
    },
    {
      mapFn: 'getListClassified',
      isRule: false,
      title: '获取列表',
      path: classified.getListClassified,
      params: {
        xsiteid: ['站点ID', 'String', '必填'],
        status: ['归类状态', 'String', '选填'],
        category_name: ['搜索归类名称', 'String', '选填'],
        page_size: ['每页大小，默认20条', 'Number', '选填', 20],
        page_token: ['当前获取列表页码', 'Number', '选填', 1],
      },
      disabled: true,
      role: 'getListClassified',
    },
    {
      mapFn: 'addClassified',
      isRule: false,
      title: '添加记录',
      path: classified.addClassified,
      data: {
        xsiteid: ['站点ID', 'String', '必填'],
        category_name: ['搜索归类名称', 'String', '必填'],
        status: ['归类状态', 'String', '必填', 'Y'],
        intro: ['搜索归类名称', 'String', '选填'],
      },
      disabled: true,
      role: 'addClassified',
    },
    {
      mapFn: 'updateClassified',
      isRule: false,
      title: '更新记录',
      path: classified.updateClassified,
      data: {
        category_id: ['归类ID', 'String', '必填'],
        xsiteid: ['站点ID', 'String', '必填'],
        category_name: ['搜索归类名称', 'String', '必填'],
        status: ['归类状态', 'String', '必填', 'Y'],
        intro: ['搜索归类名称', 'String', '选填'],
      },
      disabled: true,
      role: 'updateClassified',
      method: 'put',
    },

    {
      mapFn: 'getListClassifiedRule',
      isRule: false,
      title: '获取归类配置列表',
      path: classified.getListClassifiedRule,
      params: {
        xsiteid: ['站点ID', 'String', '必填'],
        category_id: ['搜索归类ID', 'String', '选填'],
        page_size: ['每页大小，默认20条', 'Number', '选填', 20],
        page_token: ['当前获取列表页码', 'Number', '选填', 1],
      },
      disabled: true,
      role: 'getListClassifiedRule',
    },
    {
      mapFn: 'getByIdClassifiedRule',
      isRule: false,
      title: '获取归类配置信息',
      path: classified.getByIdClassifiedRule,
      params: {
        xsiteid: ['站点ID', 'String', '必填'],
        set_id: ['归类配置ID', 'String', '必填'],
      },
      disabled: true,
      role: 'getByIdClassifiedRule',
    },
    {
      mapFn: 'addClassifiedRule',
      isRule: false,
      title: '添加归类配置记录',
      path: classified.addClassifiedRule,
      data: {
        xsiteid: ['站点ID', 'String', '必填'],
        category_id: ['搜索归类ID', 'String', '必填'],
        selection_method: ['验证方式 正选=regular 反选=inverse', 'String', '必填', 'regular'],
        film_data: ['影片数据', 'String', '选填'],
      },
      disabled: true,
      role: 'addClassifiedRule',
    },
    {
      mapFn: 'updateClassifiedRule',
      isRule: false,
      title: '更新归类配置记录',
      path: classified.updateClassifiedRule,
      data: {
        set_id: ['归类配置ID', 'String', '必填'],
        xsiteid: ['站点ID', 'String', '必填'],
        category_id: ['搜索归类ID', 'String', '必填'],
        selection_method: ['验证方式 正选=regular 反选=inverse', 'String', '必填', 'regular'],
        film_data: ['影片数据', 'String', '选填'],
      },
      disabled: true,
      role: 'updateClassifiedRule',
      method: 'put',
    },

  ],
}


